@@ -1,3 +1,11 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+"""
+Created on Tue Aug 10 14:09:59 2021
+
+@author: ekhaledian
+"""
+
 
 import pandas as pd
 import numpy as np
@@ -17,7 +25,8 @@ class PeptideSearch():
          def __init__(self, sequence , ID):
              self.sequence = sequence
              self.ID = ID
-        
+    
+    #read sequences from a fasta file and return them as a list of Fasta(sequence , ID)    
     def read_fasta(self):
         file1 = open(self.Fasta_File, 'r')
         Lines = file1.readlines()
@@ -41,6 +50,7 @@ class PeptideSearch():
         List=List[1:]
         return List
     
+    #read sequences and IDs from a fasta and return a dataframe    
     def FastatoCsv(self):
         df2=pd.DataFrame()
         records = self.read_fasta()
@@ -50,16 +60,21 @@ class PeptideSearch():
         df2[ "sequence"]= sequence
         return df2
     
+    #read sequences from a .txt file or from a list 
     def read_Peptides(self):
+        if type(self.Peptides)==list:
+            return self.Peptides
         file1 = open(self.Peptides, 'r')
         Lines = file1.readlines()
         Lines= [i.strip() for i in Lines]
         return list(Lines)
 
-
-    def ExactMatch(self):
+     #find exact matches for a list of peptides in the Fasta_File
+    def ExactMatch(self, Peptides=[]):
+        if len(Peptides)==0:
+            Peptides= self.read_Peptides()
         db=self.FastatoCsv()
-        Peptides= self.read_Peptides()
+
         DBString=db['sequence']
         L=list()
         pept=list()
@@ -101,14 +116,16 @@ class PeptideSearch():
             while(Occurances>0):
                 b= string_index[j]
                 Occurances = Occurances-1
-                geneid= db['geneid'][b]
+                geneid= db['geneid'][b][1:]
                 start_ends = str(start_index[j])+ '--'+ str(start_index[j]+len(lista[i]))
                 j=j+1
                 df = df.append({'Peptide':lista[i],'geneid/s':geneid, 'start/s':start_ends, 'ExactMatch/OneMismatch':'ExactMatch'}, ignore_index=True)
         return df, pList
 
-
-    def OneMismatch(self, peptides):
+    #find matches with one mismatch for a list of peptides in the Fasta_File
+    def OneMismatch(self, peptides=[]):
+        if len(peptides)==0:
+            peptides= self.read_Peptides()
 
         db=self.FastatoCsv()
         DBString=db['sequence']
@@ -129,20 +146,21 @@ class PeptideSearch():
                     #check for the same sequence
                     if(len(common)>0):
                         idx= common.pop()
-                        geneid = db['geneid'][idx]
+                        geneid = db['geneid'][idx][1:]
                         s1= db['sequence'][idx].find(str1)
                         s2= db['sequence'][idx].find(str2)
                         if s2==(s1+len(str1)+1) or s1==0 or s2==0:
                             start_ends= s1
                             dfrelay1 = dfrelay1.append({'Peptide':strp, 'geneid/s':geneid, 'start/s':start_ends, 'ExactMatch/OneMismatch':'OneMismatch'}, ignore_index=True)
                             df=df.append(dfrelay1,ignore_index=True)
-                        else:
-                            NoMatch.add(strp)
+                    else:
+                        NoMatch.add(strp)
                             
 
 
         return df, list(NoMatch)
     
+    #Combine Exact match and one mismatch functions
     def MatchFinder(self):
         df, pList= self.ExactMatch()
         df2, N= self.OneMismatch(pList)
@@ -150,7 +168,7 @@ class PeptideSearch():
         dffinal.to_csv(str(self.Fasta_File)+"Matches.csv")
         return dffinal, N
     
-
+    #search for a peptide in a sequence
     def SequenceSearch(Peptide, Sequence):
         Result, Index= -1, -1 
         x= Sequence.find(Peptide)
@@ -180,9 +198,10 @@ class PeptideSearch():
         return Result, Index   
                     
 
-# p= PeptideSearch("Peptides.txt", "Test.fasta",)
-# df, pList= p.ExactMatch()
-# df2, N= p.OneMismatch(pList)
-#d, s= PeptideSearch.SequenceSearchs("sl", "abcsm")
+# List=["ACH", "K"]
+# p= PeptideSearch(List, "Test.fasta",)
+# df, pList= p.ExactMatch(List)
+# df2, N= p.OneMismatch(List)
+# d, s= PeptideSearch.SequenceSearchs("sl", "abcsm")
 
 
